@@ -16,7 +16,7 @@ compareRedcapVersion <- function(current_version, required_version){
   #* if current version is unknown, return -1
   if (current_version == "Version Unknown") return(-1)
 
-  check_current <- grepl("(\\d{1,3}|\\d{1,3}[.]\\d{1,3}|\\d{1,3}[.]\\d{1,3}[.]\\d{1,3})")
+  check_current <- grepl("(\\d{1,3}|\\d{1,3}[.]\\d{1,3}|\\d{1,3}[.]\\d{1,3}[.]\\d{1,3})", check_current)
   
   #* If a version style is not recognized, set the current version to 'Version Unknown'
   if (!check_current) current_version <- "Version Unknown"
